@@ -13,9 +13,7 @@ Usage::
     describe_report_definitions_paginator: DescribeReportDefinitionsPaginator = client.get_paginator("describe_report_definitions")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from __future__ import annotations
-
-from typing import Generator
+from typing import Iterator, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_cur.type_defs import (
     DescribeReportDefinitionsResponseTypeDef,
@@ -28,12 +26,12 @@ __all__ = ("DescribeReportDefinitionsPaginator",)
 
 class DescribeReportDefinitionsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeReportDefinitions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.49/reference/services/cur.html#CostandUsageReportService.Paginator.DescribeReportDefinitions)
+    [Paginator.DescribeReportDefinitions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/cur.html#CostandUsageReportService.Paginator.DescribeReportDefinitions)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[DescribeReportDefinitionsResponseTypeDef, None, None]:
+    ) -> Iterator[DescribeReportDefinitionsResponseTypeDef]:
         """
-        [DescribeReportDefinitions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.49/reference/services/cur.html#CostandUsageReportService.Paginator.DescribeReportDefinitions.paginate)
+        [DescribeReportDefinitions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/cur.html#CostandUsageReportService.Paginator.DescribeReportDefinitions.paginate)
         """
